@@ -59,11 +59,17 @@ class SqliteDao:
         extended_feature = isinstance(column_dict, ColumnDict)
         query = "CREATE TABLE IF NOT EXISTS {} ( ".format(table_name)
         columns = []
+        primary_keys = []
         for k, v in column_dict.items():
             if extended_feature:
                 columns.append(ColumnDict.to_query(k, v))
+                if v["primary_key"]:
+                    primary_keys.append(k)
             else:
                 columns.append("{} {}".format(k, v))
+        if primary_keys:
+            primary_key_str = "PRIMARY KEY({})".format(", ".join(primary_keys))
+            columns.append(primary_key_str)
         query += ", ".join(columns) + " )"
         cursor = self.conn.cursor()
         cursor.execute(query)
@@ -268,6 +274,8 @@ class SqliteDao:
 
     # Find item based on a index only table_item, returns the full item if found
     def find_item(self, table_item):
+        if not table_item.INDEX_KEYS:
+            raise NoIndexError("This table does not have index keys specified, use get_items instead")
         result = self.search_table(table_item.get_table(), table_item.get_index_dict())
         if result:
             return type(table_item)(result[0])
@@ -318,19 +326,39 @@ class ColumnDict(dict):
             query += value["additional_attributes"]
         return query
 
-    def add_column(self, column_name, data_type, additional_attributes=None):
-        self[column_name] = {"type": data_type, "additional_attributes": additional_attributes}
+    def add_column(self, column_name, data_type, additional_attributes=None, primary_key=False):
+        self[column_name] = {
+            "type": data_type,
+            "additional_attributes": additional_attributes,
+            "primary_key": primary_key
+        }
         return self
 
 
 class TableItem:
 
     TABLE_NAME = "table_this_item_belong_to"
-    INDEX_KEYS = ["dummy_index_1", "dummy_index_2"]
+    INDEX_KEYS = ["dummy_index_1"]
+    ALL_COLUMNS = {} # column name to type map
 
     # Row_tuple builds the correspondence to table
-    def __init__(self, row_tuple):
-        self.row_tuple = row_tuple
+    def __init__(self, row_tuple=None, **kwargs):
+        if row_tuple:
+            self.row_tuple = row_tuple
+        elif len(kwargs) and type(self).ALL_COLUMNS:
+            ALL_COLUMNS = type(self).ALL_COLUMNS
+            row_tuple = {col: None for col in ALL_COLUMNS.keys()}
+            for key, val in kwargs.items():
+                if key in ALL_COLUMNS:
+                    row_tuple[key] = ALL_COLUMNS[key](val)
+            for index in type(self).INDEX_KEYS:
+                if index not in row_tuple:
+                    raise "ALL_COLUMNS must contain index fields"
+                if row_tuple[index] is None:
+                    raise "index field must be populated"
+            self.row_tuple = row_tuple
+        else:
+            raise "Must pass in either a tuple object or field arguments"
 
     @classmethod
     def get_table(cls):
@@ -349,5 +377,9 @@ class TableItem:
             print("Row tuple does not contain index: {}".format(e))
 
 
+class NoIndexError(Exception):
+    pass
+
+
 class DuplicateError(Exception):
     pass
